@@ -307,3 +307,15 @@ say = Say()
 
 fmt = Say(encoding=None, retvalue=True, silent=True)
 fmt.setfiles([])
+
+# TODO: fmt() is such a core feature - maybe a subclas not just an instance configuration?
+
+def caller_fmt(*args, **kwargs):
+    """
+    Like fmt(), but iterpolating strings not from the caller's context, but the caller's caller's
+    context.  It sounds uber meta, but it helps easily make other routines be able to do what
+    fmt() can do.
+    """
+    kwargs['_callframe'] = inspect.currentframe().f_back.f_back
+    return fmt(*args, **kwargs)
+    
